@@ -1174,6 +1174,22 @@ class Proxy(proxy.BaseProxy):
         """
         return self._get(_quota.Quota, quota)
 
+    def get_quota_default(self, quota):
+        """Get a default quota
+
+        :param quota: The value can be the ID of a default quota or a
+                      :class:`~openstack.network.v2.quota.QuotaDefault`
+                      instance. The ID of a default quota is the same
+                      as the project ID for the default quota.
+
+        :returns: One :class:`~openstack.network.v2.quota.QuotaDefault`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+                 when no resource can be found.
+        """
+        project_id = resource.Resource.get_id(quota)
+        return self._get(_quota.QuotaDefault,
+                         path_args={'project': project_id})
+
     def quotas(self, **query):
         """Return a generator of quotas
 
@@ -1228,10 +1244,10 @@ class Proxy(proxy.BaseProxy):
         self._delete(_rbac_policy.RBACPolicy, rbac_policy,
                      ignore_missing=ignore_missing)
 
-    def find_rbac_policy(self, id, ignore_missing=True):
+    def find_rbac_policy(self, rbac_policy, ignore_missing=True):
         """Find a single RBAC policy
 
-        :param id: The ID of a RBAC policy.
+        :param rbac_policy: The ID of a RBAC policy.
         :param bool ignore_missing: When set to ``False``
             :class:`~openstack.exceptions.ResourceNotFound` will be
             raised when the resource does not exist.
@@ -1240,7 +1256,7 @@ class Proxy(proxy.BaseProxy):
         :returns: One
             :class:`~openstack.network.v2.rbac_policy.RBACPolicy` or None
         """
-        return self._find(_rbac_policy.RBACPolicy, id,
+        return self._find(_rbac_policy.RBACPolicy, rbac_policy,
                           ignore_missing=ignore_missing)
 
     def get_rbac_policy(self, rbac_policy):
